pub async fn run_all<F: ExecutorFactory>(factory: &F) -> ConformanceReportExpand description
Runs every check against a fresh executor each and reports.
Never panics and never stops early.
pub async fn run_all<F: ExecutorFactory>(factory: &F) -> ConformanceReportRuns every check against a fresh executor each and reports.
Never panics and never stops early.