pub struct PolicyDecision {
pub command_ref: CommandRef,
pub policy: CommandPolicy,
pub requires_interaction: Option<InteractionKind>,
pub allowed: bool,
pub reason_key: String,
}Expand description
The outcome of evaluating policy for one command.
Fields
command_ref: CommandRefThe command.
policy: CommandPolicyThe policy that applied.
requires_interaction: Option<InteractionKind>Interaction that would authorize the command when not allowed now.
allowed: boolWhether the command may execute with its current origin.
reason_key: StringKey of the user-facing reason (see reason).